Tierkreis Python API Documentation
==================================

This is the API documentation for the Tierkreis Python package.


.. autosummary::
   :toctree: generated
   :template: autosummary/module.rst
   :recursive:

   tierkreis


Indices and tables
~~~~~~~~~~~~~~~~~~

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
